package com.link.core.util.redisclient;

import com.alibaba.fastjson.JSONObject;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.ScanParams;
import redis.clients.jedis.ScanResult;
import redis.clients.jedis.Tuple;

public class LinkRedisSingleClient implements LinkRedisClient {
   private static Logger logger = LoggerFactory.getLogger(LinkRedisSingleClient.class);
   private Jedis jedis;

   public LinkRedisSingleClient(Jedis jedis) {
      this.jedis = jedis;
   }

   public String get(String key) {
      return this.jedis.get(key);
   }

   public String hget(String key, String propertyKey) {
      return this.jedis.hget(key, propertyKey);
   }

   public void close() {
      this.jedis.close();
   }

   public Long ttl(String s) {
      return this.jedis.ttl(s);
   }

   public Long expire(String s, Integer tokenExpire) {
      return this.jedis.expire(s, tokenExpire);
   }

   public boolean exists(String loginInfoMapKey) {
      return this.jedis.exists(loginInfoMapKey);
   }

   public List<String> hmget(String loginInfoMapKey, String key) {
      return this.jedis.hmget(loginInfoMapKey, new String[]{key});
   }

   public List<String> hmget(String key, String[] arr) {
      return this.jedis.hmget(key, arr);
   }

   public Long hdel(String loginInfoMapKey, String key) {
      return this.jedis.hdel(loginInfoMapKey, new String[]{key});
   }

   public Long hset(String loginInfoMapKey, String key, String value) {
      return this.jedis.hset(loginInfoMapKey, key, value);
   }

   public String hmset(String mapKey, Map<String, String> map) {
      return this.jedis.hmset(mapKey, map);
   }

   public String set(String key, String value) {
      return this.jedis.set(key, value);
   }

   public String set(String key, String value, String nxxx, String expx, int time) {
      return this.jedis.set(key, value, nxxx, expx, time);
   }

   public List<String> brpop(int i, String key) {
      return this.jedis.brpop(i, key);
   }

   public long llen(String key) {
      return this.jedis.llen(key);
   }

   public Long lpush(String key, String value) {
      return this.jedis.lpush(key, new String[]{value});
   }

   public Long lpush(String key, String... value) {
      return this.jedis.lpush(key, value);
   }

   public Long sadd(String key, String[] value) {
      return this.jedis.sadd(key, value);
   }

   public long scard(String key) {
      return this.jedis.scard(key);
   }

   public String spop(String key) {
      return this.jedis.spop(key);
   }

   public Set<String> keys(String s) {
      return this.jedis.keys(s);
   }

   public Set<byte[]> keys(byte[] pattern) {
      return this.jedis.keys(pattern);
   }

   public Long del(String[] keyStrs) {
      return this.jedis.del(keyStrs);
   }

   public Long del(String mutexKey) {
      return this.jedis.del(mutexKey);
   }

   public Long del(Set<String> keySet) {
      long tmpValue = 0L;

      for(Iterator<String> iter = keySet.iterator(); iter.hasNext(); ++tmpValue) {
         this.jedis.del((String)iter.next());
      }

      return tmpValue;
   }

   public String setex(String mutexKey, int i, String y) {
      return this.jedis.setex(mutexKey, i, y);
   }

   public String select(int dbIndex) {
      return this.jedis.select(dbIndex);
   }

   public Set<String> hkeys(String key) {
      return this.jedis.hkeys(key);
   }

   public List<byte[]> mget(byte[][] keys) {
      return this.jedis.mget(keys);
   }

   public List<String> mget(String... keys) {
      return this.jedis.mget(keys);
   }

   public Map<String, String> hgetAll(String key) {
      return this.jedis.hgetAll(key);
   }

   public List<String> lrange(String key, long start, long end) {
      return this.jedis.lrange(key, start, end);
   }

   public String ltrim(String key, long start, long end) {
      return this.jedis.ltrim(key, start, end);
   }

   public String lindex(String key, long index) {
      return this.jedis.lindex(key, index);
   }

   public Long pexpire(String key, long milliseconds) {
      return this.jedis.pexpire(key, milliseconds);
   }

   public Long hincrBy(String key, String field, long value) {
      return this.jedis.hincrBy(key, field, value);
   }

   public Double hincrByFloat(String key, String field, double value) {
      return this.jedis.hincrByFloat(key, field, value);
   }

   public Long setnx(String key, String value) {
      return this.jedis.setnx(key, value);
   }

   public String getSet(String key, String value) {
      return this.jedis.getSet(key, value);
   }

   public String rpop(String key) {
      return this.jedis.rpop(key);
   }

   public Boolean scriptExists(String key, String sha1) {
      return this.jedis.scriptExists(sha1);
   }

   public String scriptLoad(String script, String key) {
      return this.jedis.scriptLoad(script);
   }

   public Object evalsha(String sha1, int keyCount, String... params) {
      return this.jedis.evalsha(sha1, keyCount, params);
   }

   public Boolean hexists(String key, String field) {
      return this.jedis.hexists(key, field);
   }

   public Object eval(String script, List<String> keys, List<String> args) {
      return this.jedis.eval(script, keys, args);
   }

   public List<String> scan(Integer count, String matchKey) {
      List<String> list = new ArrayList();
      ScanParams params = new ScanParams();
      params.match(matchKey);
      params.count(count);
      String cursor = "0";

      do {
         ScanResult<String> scanResult = this.jedis.scan(cursor, params);
         List<String> elements = scanResult.getResult();
         if (elements != null && elements.size() > 0) {
            list.addAll(elements);
         }

         cursor = scanResult.getStringCursor();
      } while(!"0".equals(cursor));

      return list;
   }

   public List<String> hvals(String key) {
      return this.jedis.hvals(key);
   }

   public Long zrevrank(String key, String member) {
      return this.jedis.zrevrank(key, member);
   }

   public Set<String> zrevrange(String key, long start, long stop) {
      return this.jedis.zrevrange(key, start, stop);
   }

   public Double zscore(String key, String member) {
      return this.jedis.zscore(key, member);
   }

   public Long incrBy(String key, long integer) {
      return this.jedis.incrBy(key, integer);
   }

   public void scanExec(Integer count, String matchKey, RedisScanExec redisScanExec, JSONObject paramJson) throws Exception {
      new ArrayList();
      ScanParams params = new ScanParams();
      params.match(matchKey);
      params.count(count);
      String cursor = "0";

      do {
         ScanResult<String> scanResult = this.jedis.scan(cursor, params);
         List<String> elements = scanResult.getResult();
         if (elements != null && elements.size() > 0) {
            redisScanExec.redisScanExec(elements, paramJson);
         }

         cursor = scanResult.getStringCursor();
      } while(!"0".equals(cursor));

   }

   public Set<String> smembers(String key) {
      return this.jedis.smembers(key);
   }

   public boolean sismember(String key, String member) {
      return this.jedis.sismember(key, member);
   }

   public Long srem(String key, String... member) {
      return this.jedis.srem(key, member);
   }

   public String type(String key) {
      return this.jedis.type(key);
   }

   public String rename(String oldkey, String newkey) {
      return this.jedis.rename(oldkey, newkey);
   }

   public Long zrem(String key, String... member) {
      return this.jedis.zrem(key, member);
   }

   public Long zadd(String key, double score, String member) {
      return this.jedis.zadd(key, score, member);
   }

   public Long zremrangeByScore(String key, double start, double end) {
      return this.jedis.zremrangeByScore(key, start, end);
   }

   public Double zincrby(String key, double score, String member) {
      return this.jedis.zincrby(key, score, member);
   }

   public Long zcard(String key) {
      return this.jedis.zcard(key);
   }

   public Set<String> zrevrangeByScore(String key, double max, double min) {
      return this.jedis.zrevrangeByScore(key, max, min);
   }

   public Set<String> zrange(String key, long start, long end) {
      return this.jedis.zrange(key, start, end);
   }

   public void info() {
      logger.info("缓存信息：" + this.jedis.info());
   }

   public Set<Tuple> zrangeByScoreWithScores(String key, double min, double max) {
      return this.jedis.zrangeByScoreWithScores(key, min, max);
   }
}
